Improve this Doc

# Error: $interpolate:logicbug
Bug in ngMessageFormat module

    The messageformat parser has encountered an internal error.  Please file a github issue against the AngularJS project and provide this message text that triggers the bug.  Text: “{0}”

## Description

You've just hit a bug in the ngMessageFormat module provided by angular-message-format.min.js. Please file a github issue for this and provide the interpolation text that caused you to hit this bug mentioning the exact version of AngularJS used and we will fix it!

For more information about the MessageFormat syntax in interpolation expressions, please refer to MessageFormat extensions section at Angular i18n MessageFormat